<?php

namespace SimpleSAML\Module\adfs\SAML2\XML\fed;

/**
 * Class holding constants relevant for ADFS.
 *
 * @package SimpleSAMLphp
 */

class Constants
{
    /**
     * The namespace for WS-FED protocol.
     */
    public const NS_FED = 'http://docs.oasis-open.org/wsfed/federation/200706';
}
